@@ -19,8 +19,8 @@ namespace FBB
 
 //     If, when looking for /t*/m*/ps*/ the initial path /t*/m* does not exist
 // then there's no reason for inspecting /t*/mp*/s*/ as it won't exist either.
-// 
-// In those cases the non-existing path is pruned (i.e., t*/m* is) an 
+//
+// In those cases the non-existing path is pruned (i.e., t*/m* is) an
 // subpatterns of the pruned path (e.g., t*/mp*) are not considered (and so:
 // not globbed)
 
@@ -43,7 +43,7 @@ class Alternatives: public std::deque<std::string>
         TRUE
     };
 
-    TriState d_addRoot; // true: always also search /, ifEmpty: only if 
+    TriState d_addRoot; // true: always also search /, ifEmpty: only if
                         //      search from $HOME fails
     Command d_command;
     History d_history;
@@ -81,17 +81,17 @@ class Alternatives: public std::deque<std::string>
 
         FBB::ArgConfig &configFile();
 
-        size_t set(char const *longKey, char const *const * const begin, 
-                                    char const *const *const end, 
+        size_t set(char const *longKey, char const *const * const begin,
+                                    char const *const *const end,
                                     size_t notFound);
 
         void getCwd(std::unique_ptr<char> *dest);
 
-        std::string determineInitialDirectory();        
+        std::string determineInitialDirectory();
         ViableResult globFrom(std::string initial);
 
         void checkCase(std::string &head, size_t *idx) const;
-    
+
         void add(char const *path);         // also determines d_nPatterns
 
         struct GlobContext
@@ -101,22 +101,22 @@ class Alternatives: public std::deque<std::string>
             std::set<std::string> ignore;
         };
         ViableResult glob(std::string initial, GlobContext &context);
-        ViableResult generalizedGlob(std::string initial, 
+        ViableResult generalizedGlob(std::string initial,
                                                 GlobContext &context);
 
-        void globHead(std::string const &initial, 
+        void globHead(std::string const &initial,
                       std::string searchCmd, GlobContext &context);
-        void globPattern(std::string pattern, 
+        void globPattern(std::string pattern,
                                 std::string &searchCmd, size_t *idx,
                                 GlobContext &context);
 
         static void globFilter(char const *entry, GlobContext &context);
 
-        static void addIgnored(std::string const &line, 
+        static void addIgnored(std::string const &line,
                                 std::set<std::string> &ignoreSet);
 
-        static bool matchIgnore(std::string const &ignore, char const *entry);
-
+        static bool matchIgnore(std::string const &ignore,
+                                std::string const &entry);
 };
 
 inline void Alternatives::update(size_t index)
@@ -125,5 +125,3 @@ inline void Alternatives::update(size_t index)
 }
 
 #endif
-
-
